The dataset contains cases from a study that was conducted between 1958 and 1970 at the University of Chicago's Billings Hospital on the survival of patients who had undergone surgery for breast cancer.
habermanA data frame with 306 instances, 81 of which belong to positive class, and 4 variables:
Age of patient at time of operation. Discrete attribute.
Patient's year of operation. Discrete attribute.
Number of positive axillary nodes detected. Discrete attribute.
Two possible survival status: positive(survival rate of less than 5 years), negative (survival rate or more than 5 years).
Original available in UCI ML Repository.